================================
PESummary Configuration Settings
================================

Most of the settings used by `pesummary` are controlled by the `pesummary.conf`
module. This module includes settings like the default matplotlib style
properties and default image captions.

Below is the matplotlib style file that is used by default,

.. literalinclude:: ../../pesummary/conf/matplotlib_rcparams.sty
    :language: python

Below are the image captions that are used,

.. literalinclude:: ../../pesummary/conf/caption.py
    :language: python

Below, are the default settings used by PESummary,

.. literalinclude:: ../../pesummary/conf/configuration.py
    :language: python
